/*
  * Copyright (c) 2019 Ignacio Francisco Ramírez Paulino and Ignacio Hounie
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Affero General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or (at
  * your option) any later version.
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero
  * General Public License for more details.
  * You should have received a copy of the GNU Affero General Public License
  *  along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
/**
 * \file paco_inpainting_problem.h
 * \brief PACO-DCT inpainting problem definition.
 *
 * Here we provide a concrete instance of the PACO problem, the PACO-DCT Inpainting
 * algorithm. This module defines the cost functions, corresponding proximal operators
 * and feasible sets of the problem so that the PACO ADMM generic algorithm can solve it.
 * The module also defines a particular initialization mechanism for this problem,
 * and a ``sentinel'' function whose task is to report on the advance of the algorithm
 * thrughout the iterations.
 */
#ifndef PACO_INPAINTING_PROBLEM_H
#define PACO_INPAINTING_PROBLEM_H


#include "paco_problem.h"
/**
 * \brief Creates an instance of the PACO-DCT inpainting problem.
 * The mask suffices for defining all problem-related initialization.
 * Input data, etc, is loaded afterwards before processing each channel
 */
void paco_dct_inpainting_problem_init(const gsl_matrix_float* mask);

/**
 * change DCT weights: if the argument is null, the weights will be estimated
 * from the known patches of the input signal
 */
void paco_problem_set_weights(const gsl_vector_float* weights);

/**
 * prefix for intermediate result images. An empty or null string 
 * will disable saving intermediate images.
 */
void paco_problem_set_iter_prefix(const char* prefix);

#endif
