/*
  * Copyright (c) 2019 Ignacio Francisco Ramírez Paulino and Ignacio Hounie
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Affero General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or (at
  * your option) any later version.
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero
  * General Public License for more details.
  * You should have received a copy of the GNU Affero General Public License
  *  along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
/**
 * \file paco_linalg.h
 * \brief some simple gsl-like utilities not present in gsl_vector_float.h, gsl_matrix_float.h or gsl_linalg.h
 */
#ifndef PACO_LINALG_H
#define PACO_LINALG_H
#include <gsl/gsl_matrix_float.h>
#include <gsl/gsl_blas.h>
#include <gsl/gsl_linalg.h>

/// sum of vector components
double gsl_vector_float_sum ( const gsl_vector_float* v );

/// squared Euclidean distance between two vectors
double gsl_vector_float_dist2_squared ( const gsl_vector_float* u, const gsl_vector_float* v );

/// cumulative difference between two vectors
double gsl_vector_float_dif_sum ( const gsl_vector_float* u, const gsl_vector_float* v );

/// signed sum of all elements in a matrix
double gsl_matrix_float_sum ( const gsl_matrix_float* A );

/// sum of the signed difference between two matrices
double gsl_matrix_float_dif_sum ( const gsl_matrix_float* A, const gsl_matrix_float* B );

/// squared Frobenius-norm based distance betwen two matrices
double gsl_matrix_float_dist2_squared ( const gsl_matrix_float* A, const gsl_matrix_float* B );

/// Frobenius norm of a matrix
double gsl_matrix_float_frobenius(const gsl_matrix_float* A);

/// squared Frobenius norm of a matrix
double gsl_matrix_float_frobenius_squared(const gsl_matrix_float* A);

#endif
