#!/bin/bash
#
#
# Copyright (c) 2019 Ignacio Francisco Ramírez Paulino and Ignacio Hounie
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or (at
# your option) any later version.
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero
# General Public License for more details.
# You should have received a copy of the GNU Affero General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.
#
# PACO-DCT demo
#
# the arguments for this demo are as follows:
# -w 16        use square patches of size 16x16
# -s 2         use a stride of 2 (12.5% area overlap)
# -m 1024      run up to 1024 iterations
# -l 10        parameter lambda of the ADMM algorithm
# -e           parameter epsilon in the paper
# -k 0.975     parameter kappa of the ADMM algorithm
# -$*          the user can override any setting from the command line by passing
#              his/her own arguments to demo.sh
#
ARGS="-w 64 -s 2 -m 256 -e 1e-5 -l 10 -k 0.99 -p iter $*"
#
# download the KODAK dataset
#
cd data/image
./get_kodak.sh
cd -
#
# set up problem
#
type="color"
m="2"         # mask 2: thick jigsaw borders
i="19"        # image 19: portrait image of a lighthouse
#
# output directory
#
out="./results/images/kodak/${type}"
#
# metrics per iteration are saved here
#
metrics="./results/metrics/kodak/${type}"
mkdir -p ${out}
mkdir -p ${metrics}
#
# mask, input and output filenames
#
mask="data/image/masks/inpaint_512x768_${m}.png"
input="data/image/${type}/kodak/kodim${i}.png"
output="${out}/kodim${i}_${m}.png"
coefs="data/weights/dct_weights_w016_c3.txt"
#
# compile PACO
#
make -C code clean
DEBUG=1 make -C code
#
# run PACO
#
gdb ./code/paco_dct_inpainting_tool -ex "run --dct-weights=${coefs} ${ARGS} ${input} ${mask} ${output} ${input}"
#
# display the result (requires imagemagick)
#
    
